@@ -17,9 +17,10 @@ class Unsilence:
 
     def __init__(self, input_file: Path, temp_dir: Path = Path(".tmp")):
         """
-        Initializes a new Unsilence Obqject
         :param input_file: The file that should be processed
+        :type input_file: Path
         :param temp_dir: The temp dir where temporary files can be saved
+        :type temp_dir: Path
         """
         self.__input_file = Path(input_file)
         self.__temp_dir = Path(temp_dir)
@@ -39,16 +40,11 @@ class Unsilence:
     def detect_silence(self, **kwargs):
         """
         Detects silence of the file (Options can be specified in kwargs)
-        :param kwargs: Keyword Args, more information below
-        :return: A generated Intervals object
 
-        kwargs:
-            silence_level: Threshold of what should be classified as silent/audible (default -35) (in dB)
-            silence_time_threshold: Resolution of the ffmpeg detection algorithm (default 0.5) (in seconds)
-            short_interval_threshold : The shortest allowed interval length (default: 0.3) (in seconds)
-            stretch_time: Time the interval should be enlarged/shrunken (default 0.25) (in seconds)
-            on_silence_detect_progress_update: Function that should be called on progress update
-                (called like: func(current, total))
+        :param `\**kwargs`: Remaining keyword arguments are passed to :func:`~unsilence.lib.detect_silence.DetectSilence.detect_silence`
+
+        :return: A generated Intervals object
+        :rtype: ~unsilence.lib.intervals.Intervals.Intervals
         """
         self.__intervals = detect_silence(self.__input_file, **kwargs)
         return self.__intervals
@@ -56,7 +52,10 @@ class Unsilence:
     def set_intervals(self, intervals: Intervals):
         """
         Set the intervals so that they do not need to be re-detected
+
         :param intervals: Intervals collection
+        :type intervals: ~unsilence.lib.intervals.Intervals.Intervals
+
         :return: None
         """
         self.__intervals = intervals
@@ -64,17 +63,25 @@ class Unsilence:
     def get_intervals(self):
         """
         Get the current Intervals so they can be reused if wanted
+
         :return: Intervals collection
+        :rtype: ~unsilence.lib.intervals.Intervals.Intervals
         """
         return self.__intervals
 
     def estimate_time(self, audible_speed: float = 6, silent_speed: float = 1):
         """
         Estimates the time (savings) when the current options are applied to the intervals
+
         :param audible_speed: The speed at which the audible intervals get played back at
+        :type audible_speed: float
         :param silent_speed: The speed at which the silent intervals get played back at
+        :type silent_speed: float
+
+        :raises: **ValueError** -- If silence detection was never run
+
         :return: Dictionary of time information
-        :exception: ValueError if silence detection was never run
+        :rtype: dict
         """
         if self.__intervals is None:
             raise ValueError("Silence detection was not yet run and no intervals where given manually!")
@@ -84,22 +91,12 @@ class Unsilence:
     def render_media(self, output_file: Path, **kwargs):
         """
         Renders the current intervals with options specified in the kwargs
-        :param output_file: Where the final file should be saved at
-        :param kwargs: Keyword args, more information below
-        :return: None
 
-        kwargs:
-            audio_only: Whether the output should be audio only (bool)
-            audible_speed: The speed at which the audible intervals get played back at (float)
-            silent_speed: The speed at which the silent intervals get played back at (float)
-            audible_volume: The volume at which the audible intervals get played back at (float)
-            silent_volume: The volume at which the silent intervals get played back at (float)
-            drop_corrupted_intervals: Whether corrupted video intervals should be discarded or tried to recover (bool)
-            threads: Number of threads to render simultaneously (int > 0)
-            on_render_progress_update: Function that should be called on render progress update
-                (called like: func(current, total))
-            on_concat_progress_update: Function that should be called on concat progress update
-                (called like: func(current, total))
+        :param output_file: Where the final file should be saved at
+        :type output_file: Path
+        :param `\**kwargs`: Remaining keyword arguments are passed to :func:`~unsilence.lib.render_media.MediaRenderer.MediaRenderer.render`
+       
+        :return: None
         """
         if self.__intervals is None:
             raise ValueError("Silence detection was not yet run and no intervals where given manually!")
@@ -110,7 +107,8 @@ class Unsilence:
     def cleanup(self):
         """
         Cleans up the temporary directories, called automatically when the program ends
-        :return:
+
+        :return: None
         """
         if self.__temp_dir.exists():
             shutil.rmtree(self.__temp_dir)
